| package |
package := Package name: 'BMP2Icon'.
package paxVersion: 0;
	basicComment: 'What is it?
===========                                                                 
	This package allows you to convert a Bitmap image into an Icon.
	This is very useful when you need/want to change the icon of a class in you model or project.

Usage
=====                                                                 

	| bitmap icon | 
	bitmap := Bitmap fromFile: (File workingDirectory,  ''winrar.bmp'').
	icon := bitmap asIcon.
	icon inspect.
	bitmap inspect.

How to set the icon message of a class?
=======================================
YourClass>>icon                                                              
	" Answers an Icon that can be used to represent this class."                                                          

	^(Bitmap fromFile: (File workingDirectory,  ''winrar.bmp'')) asIcon 
	

Copyright                                                                 
=========                                                                                                                                          
   Copyright (C) 2004 by Hernan Galante <galanteh@smalltalking.net>                                                                       
   This goodie is absolutely free. If you plan to use it in a commercial version, please let me know. I won''t ask you money, just it is a pleasure to know that a litle work like this is useful ;-)'.


package methodNames
	add: #Bitmap -> #asIcon;
	add: #UserLibrary -> #createIconIndirect:;
	yourself.

package binaryGlobalNames: (Set new
	yourself).

package globalAliases: (Set new
	yourself).

package allResourceNames: (Set new
	yourself).

package setPrerequisites: (IdentitySet new
	add: 'C:\Archivos de programa\Dolphin Smalltalk 5.1\Object Arts\Dolphin\Base\Dolphin';
	add: 'C:\Archivos de programa\Dolphin Smalltalk 5.1\Object Arts\Dolphin\MVP\Base\Dolphin MVP Base';
	yourself).

package!

"Class Definitions"!


"Global Aliases"!


"Loose Methods"!

!Bitmap methodsFor!

asIcon
	" Converts the receiver to an Icon image."

	| iconInfo maskBitmap result |
	maskBitmap := Bitmap new
				isTransparent: true; 
				yourself.
	iconInfo := ICONINFO new.
	iconInfo 
		hbmColor: self handle;
		hbmMask: maskBitmap handle.
	result := UserLibrary default createIconIndirect: iconInfo.
	result isNil ifTrue: [ ^self error: 'could not create the icon' ].
	^Icon fromHandle: result! !
!Bitmap categoriesFor: #asIcon!converting!public! !

!UserLibrary methodsFor!

createIconIndirect: aICONINFO
	" Creates an icon or cursor from an ICONINFO structure."

	<stdcall: handle CreateIconIndirect ICONINFO*>
	^self invalidCall! !
!UserLibrary categoriesFor: #createIconIndirect:!public!win32 functions-menu! !

"End of package definition"!

"Source Globals"!

"Classes"!

"Binary Globals"!

"Resources"!

